# 0 LOAD LIBRARIES  ------------------------------------------------------------
## R version 3.6.2
## If ggtree is not installed
if (!requireNamespace("BiocManager", quietly = TRUE))
  install.packages("BiocManager")
BiocManager::install("ggtree")

library(ggtree) #2.0.1
library(picante) # 1.8
library(quantreg) # 5.54
library(reshape2) # 1.4.3
library(ggplot2) # 3.2.1
library(grid) # 3.6.2
library(gtable) # 0.3.0
library(ape) # 5.3
library(magrittr) # 1.5


## 1 Fig 1 --------------------------------------------------------------------
## 1.1 Fig 1(A) tree ----------------------------------------------------------
names <- c(
  kr = "italic(K[r])",
  lac="Lac",
  cel="Cel",
  leu="Leu",
  pho="Pho") # facet labbler

cols <- c(Ascomycota = "firebrick2", Basidiomycota = "purple", Mucoromycotina = "blue")

tree <- read.tree("tree-data.nwk") # change working directory if necessary
pt <- ggtree(tree, size = 0.2, linetype = 1, layout = "rectangular", color = "grey20") 

## rotate and flip the layout
ptr <- ggtree::rotate(pt, node = 39)
ptr <- ggtree::rotate(ptr, node = 59)
ptr <- ggtree::rotate(ptr, node = 34)
ptr <- flip(ptr, 36, 38)
  
ptr <- ggtree::rotate(ptr, node = 55)
ptr <- ggtree::rotate(ptr, node = 52)
ptr <- ggtree::rotate(ptr, node = 42)
ptr <- flip(ptr, 44, 51)

# The branches without tipnames
p <- ptr + scale_y_continuous(limits = c(0.5,31.5)) +
  scale_x_continuous(limits = c(0, 0.45)) +
  geom_tiplab(align = T, offset = 0.02, size = 3) 

p


## 1.2 Fig 1(A) Tukey boxplot-------------------------------------------------
### create data
df <- read.csv("traits-data.csv") 

df1 <- df
df1$plotting_order <- as.character(rep(ptr$data$y[1:31], each = 6))
df1 <- melt(df1) 
df1$plotting_order <- as.numeric(df1$plotting_order)
### plotting
g <- ggplot(data = df1) + 
  geom_boxplot(aes(x = plotting_order, 
                   y = value, 
                   color = phylum, 
                   group = plotting_order), 
               alpha= 0.9, 
               size = 0.35) +
  facet_grid(.~variable, scales = "free", 
             labeller = as_labeller(names, default = label_parsed) ) + 
  scale_color_manual(values = cols) + 
  guides(color = "none") + 
  coord_flip() + theme_bw() + 
  theme(axis.title = element_blank(), 
        axis.text.y = element_blank(),
        strip.background = element_rect(fill = alpha("grey90", 0.75)),
        axis.ticks.y = element_blank(),
        strip.text = element_text(size = 12),
        panel.grid.minor.x = element_blank())
g

## 1.3 Fig 1(B) quantile regression--------------------------------------------
### create data
df2 <-  df %>% melt() %>% dcast(., treeID+phylum~variable, mean)
df2 <- melt(df2[,-1], id.vars = c("kr","phylum"))
taus <- c(0.1,0.25,0.5,0.75,0.9) # the quantiles 

### plotting
q <- ggplot(df2, aes(x = value, y = kr))+ 
  
  facet_wrap("variable", ncol=4, scales = "free_x", labeller = labeller(variable = names)) +
  geom_quantile(aes(x = value, y = kr), method = "rq", formula = y ~ x, 
                quantiles = taus, linetype = 1,
                size = 0.5, alpha = 0.5, color = "grey40")  +
  
  geom_point(aes(color = phylum), alpha=0.6, size = 2.5) + 
  
  scale_color_manual(values = cols) +
  
  ylab(parse(text= "italic(K[r])/~mu*m%.%h^-1")) +
  xlab("Log-transformed Enzyme Activity") +
  
  theme_bw() +
  theme( 
    axis.text  = element_text(size = 9),
    strip.background = element_rect(fill = alpha("grey90", 0.75)),
    strip.text = element_text(size = 12),
    legend.position = "left",
    panel.grid = element_blank(),
    legend.text = element_text(color = "grey20"),
    legend.title = element_text(colour = "grey20"),
    axis.text.x = element_text(angle = 90, vjust = 0.3)) +
  labs(color = " Phylum")

### add linear regression line
q <- q + geom_smooth(method = "lm", formula = y~x, size = 0.5, color = "black", se = FALSE)
q


## 1.4 Fig 1 combine elements-----------------------------------------------
### create textual grobs
#### growth rate ant unit
txt1 <- textGrob(parse(text="Growth~Rate/mu*m%.%h^-1"), 
                 gp = gpar(col = "black", cex = 1.0), 
                 name = "kr")

#### enzyme activity and unit
txt2 <- textGrob(parse(text = "Enzyme~Activity/U%.%mg[dw]^-1"), 
                 gp = gpar(col = "black", cex = 1.0),
                 name = "enzyme")

#### "A" and "B"
A <- textGrob("A", name = "A", just = c("left","top"))
B <- textGrob("B", name = "B", just = "left")


### create figural grobs
P <- ggplot_gtable(ggplot_build(p)) #tree
G <- ggplot_gtable(ggplot_build(g)) # boxplot
Q <- ggplot_gtable(ggplot_build(q)) # quantile 

### combine tree and boxplot to be grob C
P <- gtable_add_rows(P, G$heights[6],5)
P$heights <- G$heights
P$widths[7] <- P$widths[3] <- unit(0,"cm")
P$widths[4] <- unit(5.5,"pt")
P$widths[5] <- unit(1.9,"null") # tree part

G$widths[3] <- G$widths[1] <- unit(0,"cm")

C <- cbind(P, G, size = "first")

### combine texts to figures
#### add 'A' and other x axis info to D
D <- gtable_add_grob(C, txt2, t = 10, l = 16, r = 22, clip = "off")
D <- gtable_add_grob(D, txt1, t = 10, l = 14, clip = "off")
D <- gtable_add_grob(D, A, t = 1, l = 1, clip = "off")
D$heights[10] <- unit(0.7, "cm")

#### add 'B' to part B
Q <- gtable_add_grob(Q, B, t = 1, l = 1, clip = "off")

#### adjuest spacers 
Q$widths[1] <- Q$heights[1] <- D$widths[1] <- D$heights[1] <- unit(5.5,"pt")


### print Fig A
# png("fig1.png", width = 19, height = 17, units = "cm", res = 300)
# tiff("fig1.tif", width = 19, height = 17, units = "cm", res = 300)
grid.newpage()
pushViewport(viewport(layout=grid.layout(2, 1, widths = unit(1,"npc"),
                                         heights = unit(c(0.66,0.34),"npc"),
                                         just="center")))

pushViewport(viewport(layout.pos.col=1, layout.pos.row=1))
grid.draw(D)
popViewport(1)
pushViewport(viewport(layout.pos.col=1, layout.pos.row=2,
                      width=unit(1, "npc"),
                      height=unit(0.25, "npc")))
grid.draw(Q)
# dev.off() 


#---------------------------------Fig 2---------------------------------------|
## 2 Fig 2-------------------------------------------------------------------
## 2.1 Fig 2(A) PCA biplot --------------------------------------------------
# [FUNCTION] create pca data
pca.dp <- function(pca) {
  scores1 <- as.data.frame(pca$x)[,c(1,2)]
  rotation <- as.data.frame(pca$rotation) #variables this is the contribution of each variable
  arrows1 <- data.frame(x1 = rep(0, dim(rotation)[1]), y1 = rep(0, dim(rotation)[1]), 
                        x2 = rotation$PC1, y2 = rotation$PC2)
  arrows1 <- arrows1*2.5
  return(list(scores = scores1, rotation = rotation, arrow = arrows1, sdev = pca$sdev))
  
}
# data create ----
dff <- transform(df,
                 lac = log(lac+1), 
                 cel = log(cel+1),
                 leu = log(leu+1),
                 pho = log(pho+1))
dff_mean <-  dff %>% melt() %>% dcast(., treeID+phylum~variable, mean)

enzymes <- c("lac","cel","leu","pho")
pca <- prcomp(dff_mean[ ,enzymes], scale. = TRUE, center = TRUE)

# Explained variation
pr.var <- pca$sdev^2
pve <- pr.var/sum(pr.var)
pve*100 #in %

# Mirror the pca results
pca$rotation <- -pca$rotation
pca$x <- -pca$x

# dataset for plotting biplot
df_pca <- pca.dp(pca)

# dataset for linear regression between PC1 and kr
PC1 <- pca$x[,1] 
df_lm <- data.frame(PC1 = PC1,
                    kr = dff_mean$kr,
                    phylum = dff_mean$phylum)

### plotting, equivalent to biplot(pca, pc.biplot = T)
g2 <- ggplot(data = df_pca$scores, 
             aes(x = PC1/(df_pca$sdev[1]), y = PC2/(df_pca$sdev[2])) ) +
  
  geom_hline(yintercept = 0, colour = "grey40", size = 0.2) +
  geom_vline(xintercept = 0, colour = "grey40", size = 0.2) +
  
  geom_segment(data = df_pca$arrow, 
               aes(x = x1, y = y1, xend = x2, yend = y2), 
               colour = "black", arrow = arrow(length =  unit(0.12,"cm")), 
               size = 0.3) +
  
  scale_x_continuous(sec.axis = ~./2.5) +
  scale_y_continuous(sec.axis = ~./2.5) +
  
  scale_color_manual(values = cols) + 
  
 
  geom_point(aes(color = dff_mean$phylum))+
  geom_text(data = df_pca$rotation, color = "black",
            check_overlap = TRUE,
            aes(x = (abs(PC1))*2.8*PC1/abs(PC1), 
                y = (abs(PC2) + c(0.01,0.01,0.01,0.01))*2.8*PC2/abs(PC2)), 
            size = 3,  label = c("Lac","Cel", "Leu", "Pho")) + 
  
  guides(color = "none", shape = "none") +
  
  xlab("PC1(42%)")+
  ylab("PC2(24%)") +
  theme_bw() + 
  theme(panel.grid = element_blank())

g2


## 2.2 Fig 2(B) Kr vs PC1 ---------------------------------------------------
p2 <- ggplot(data = df_lm, aes(x=PC1, y = kr))+
  geom_smooth(method = "lm", color = "grey40", fill = "grey80", size = 0.3) + 
  
  geom_point(aes(color = as.factor(df_lm$phylum)),
             size = 2, alpha = 0.75, stroke = 0.6) +
  
  scale_color_manual(values = cols) + 
  ylim(-49,255) +

  xlab(parse(text= "PC1*(-0.63*Lac-0.45*Cel+0.42*Pho+0.27*Leu)"))+
  ylab(parse(text= "italic(K[r])/mu*m%.%h^-1")) +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.justification = c(0.5, 0),
        legend.text = element_text(color = "grey20"),
        legend.title = element_text(colour = "grey20")) +
  
  scale_shape_manual(values = c(19,8,17,1,3,15)) + 
  labs(color = " Phylum") + theme(legend.margin = margin(l=0,unit = "pt"),
                                  legend.box.background = element_blank(),
                                  legend.key.size = unit(10,"pt"),
                                  legend.text = element_text(size = 7),
                                  legend.title = element_text(size = 9))
p2


## 2.3 Fig 2 combine elements------------------------------------------------
### create textual grobs
A <- textGrob("A", name = "A", just = c("left"))
B <- textGrob("B", name = "B", just = c("left"))
ANO <- textGrob(vjust = unit(-1.3,"cm"), gp = gpar(cex = 0.6, col = "grey20"),
                parse(text="atop(y==26*x+99,list(R[adj]^2==0.21,p==0.005))"))


### PCA biplot grob
G <- ggplot_gtable(ggplot_build(g2))

### Kr vs PC1 grob
P <- ggplot_gtable(ggplot_build(p2))

### align G and P
for(i in 1:10){
  P$heights[i] <- G$heights[i]
}

### combine G and P
E <- cbind(G, P, size = "first")
E$heights[1] <- unit(15, "pt")
E$heights[4] <- unit(5.5, "pt")
E$heights[8] <- unit(25, "pt")
E$widths[1] <- unit(5.5, "pt")
E$widths[17] <- unit(0,"cm")
E$widths[15] <- unit(0.5,"cm")

### add anotation parts
E <- gtable_add_grob(E, A, t = 1, l = 1, clip = "off")
E <- gtable_add_grob(E, B, t = 1, l = 8, clip = "off")
E <- gtable_add_grob(E, ANO, t = 5, b = 8, r = 16, l = 18, clip = "off")

### print
# png("fig2.png", width = 18, height = 8.5, units = "cm", res = 300)
grid.newpage()
grid.draw(E)
# dev.off()
