# Growth rate trades off with enzymatic investment in soil filamentous fungi
# Weishuang Zheng1 Anika Lehmann2,3 Masahiro Ryob,c Kriszta Kezia Vályi2,3 Matthias C. Rillig2,3,* 
#  1 PKU-HKUST ShenZhen-Hong Kong Institution, Shenzhen 518057, China;
# 2 Freie Universität Berlin, Institut für Biologie, Plant Ecology, Altensteinstr. 6, D-14195 Berlin, Germany;
# 3 Berlin-Brandenburg Institute of Advanced Biodiversity Research (BBIB), D-14195 Berlin, Germany 
# * Correspondence to Matthias C. Rillig, matthias.rillig@fu-berlin.de;  +49 (0)30 838-53165

### [FUNCTION] Quantile regression at 5 quantiles
sigTaus <- function(df, taus = c(0.1,0.25,0.5,0.75,0.9)) {
  
  res <- rep(NA, length(taus))
  i <- 0
  for (tau in taus) {
    i <- i+1
    fit <- rq(df$kr ~ df[,2], tau = tau, data = df) 
    su <- summary(fit, se = "boot") 
    res[i]<- su$coefficients[2,4]
  }
  return(taus[res<0.05])
}

### [FUNCTION] Calculate p value at a given tau(quantile)
sigT <- function(df, tau) {
  fit <- rq(df$kr ~ df[,2], tau = tau, data = df) 
  su <- summary(fit, se = "boot")# based on bootstraping, so the outcome varies
  su
}

# 1 Import and transform data ----
## 1.1 Read the traits data
library(readr)
library(reshape2)
library(magrittr)

# setwd('') # set the working directory as required
df <- read.csv("traits-data.csv") # load data with replicates

df_mean <-  df %>% melt() %>% dcast(., treeID+phylum~variable, mean)
summary(df_mean) # 31x7


## 1.2 read the phylogenetic tree 
library(ape)
tree <- read.tree("tree-data.nwk")
plot(tree)

# 2 Statistic signal test based on Blomberg’ K statistics ----
library(picante)

# 2.1 Sort the traits data based on the order of the tree tips
df_ordered <- 
  data.frame(treeID = tree$tip.label) %>%
  merge(., df_mean, by = "treeID", sort = FALSE)

# 2.2 Test the phylogenetic signal of the traits
phylosignal(as.vector(df_ordered$kr), tree, checkdata = FALSE)
phylosignal(as.vector(df_ordered$lac), tree, checkdata = FALSE)
phylosignal(as.vector(df_ordered$leu), tree, checkdata = FALSE)
phylosignal(as.vector(df_ordered$cel), tree, checkdata = FALSE)
phylosignal(as.vector(df_ordered$pho), tree,  checkdata = FALSE) 

# 3 Linear regression and quantile regression between Kr~enzyme activities ----
## 3.1 Data transformation
dff <- transform(df,
                 lac = log(lac+1), 
                 cel = log(cel+1),
                 leu = log(leu+1),
                 pho = log(pho+1))
dff_mean <-  dff %>% melt() %>% dcast(., treeID+phylum~variable, mean)

## 3.2 linear regreesion
summary(lm(kr~lac, data = dff_mean))
summary(lm(kr~cel, data = dff_mean))
summary(lm(kr~leu, data = dff_mean))
summary(lm(kr~pho, data = dff_mean))

## 3.3 Quantile regression 
library(quantreg) 

### find the significant quantiles 
sigTaus(dff_mean[,c("kr","lac")])
sigT(dff[,c("kr","lac")], 0.9)
sigT(dff[,c("kr","lac")], 0.75)

sigTaus(dff_mean[,c("kr","cel")])
sigT(dff[,c("kr","cel")], 0.9)

sigTaus(dff_mean[,c("kr","leu")])
sigT(dff[,c("kr","leu")], 0.5)

sigTaus(dff_mean[,c("kr","pho")])

## 4 Linear regression between Kr and PC1 ----
### 4.1 Pincipal conponent analysis (PCA) ----
enzymes <- c("lac","cel","leu","pho")
pca <- prcomp(dff_mean[ ,enzymes], scale. = TRUE, center = TRUE)

# Explained variation
pr.var <- pca$sdev^2
pve <- pr.var/sum(pr.var)
pve*100 #in %

# Mirror the pca results
pca$rotation <- -pca$rotation
pca$x <- -pca$x
biplot(pca, pc.biplot = T)

# Draw the PC1
PC1 <- pca$x[,1] # the first pincipal component

### 4.2 Linear regression between Kr and PC1 ----
fit <- lm(dff_mean$kr~PC1)
summary(fit)
plot(df_mean$kr~PC1, ylab="Kr")
abline(lm(dff_mean$kr~PC1), col = "red")

